@@ -8,9 +8,9 @@ from torcp.torcategory import TorCategory
 
 
 def transFromCCFCat(cat):
-    if re.match('(Movie)', cat, re.I):
+    if re.match(r'(Movie)', cat, re.I):
         return 'movie'
-    elif re.match('(TV)', cat, re.I):
+    elif re.match(r'(TV)', cat, re.I):
         return 'tv'
     else:
         return cat
@@ -20,7 +20,7 @@ def transToCCFCat(mediatype, originCat):
     if mediatype == 'tv':
         return 'TV'
     elif mediatype == 'movie':
-        if not re.match('(movie)', originCat, re.I):
+        if not re.match(r'(movie)', originCat, re.I):
             return 'Movie'
     return originCat
 
@@ -32,6 +32,15 @@ def tryint(instr):
         string_int = 0
     return string_int
 
+def parseTMDbStr(tmdbstr):
+    if tmdbstr.isnumeric():
+        return '', tmdbstr
+    m = re.search(r'(m(ovie)?|t(v)?)[-_]?(\d+)', tmdbstr.strip(), flags=re.A | re.I)
+    if m:
+        catstr = 'movie' if m[1].startswith('m') else 'tv'
+        return catstr, m[4]
+    else:
+        return '', ''
 
 class TMDbNameParser():
     def __init__(self, tmdb_api_key, tmdb_lang, ccfcat_hard=None):
@@ -75,7 +84,7 @@ class TMDbNameParser():
         self.poster_path = ''
         self.genre_ids =[]
 
-    def parse(self, torname, useTMDb=False, hasIMDbId=None):
+    def parse(self, torname, useTMDb=False, hasIMDbId=None, hasTMDbId=None):
         self.clearData()
         tc = TorCategory(torname)
         self.ccfcat, self.group = tc.ccfcat, tc.group
@@ -96,10 +105,17 @@ class TMDbNameParser():
         self.tmdbcat = transFromCCFCat(self.ccfcat)
 
         if useTMDb:
+            if hasTMDbId:
+                cat, tmdbstr = parseTMDbStr(hasTMDbId)
+                if tmdbstr:
+                    tmdbid, title, year = self.searchTMDbByTMDbId(cat, tmdbstr)
+                    if tmdbid > 0:
+                        print(tmdbid, title, self.ccfcat, self.year)
+                        return True
             if hasIMDbId:
                 tmdbid, title, year = self.searchTMDbByIMDbId(hasIMDbId)
                 if tmdbid > 0:
-                    print(self.ccfcat, self.year)
+                    print(tmdbid, title, self.ccfcat, self.year)
                     return
             if not self.checkNameContainsId(torname):
                 if self.tmdbcat in ['tv', 'movie', 'Other', 'HDTV']:
@@ -335,7 +351,7 @@ class TMDbNameParser():
             elif cat.lower() == 'hdtv':
                 searchList = [('multi', cntitle), ('multi', cuttitle)]
             elif cat.lower() == 'movie':
-                searchList = self.selectOrder(cntitle, cuttitle, [('movie', cntitle), ('movie', cuttitle), ('multi', cntitle), ('multi', cuttitle)])
+                searchList = self.selectOrder(cntitle, cuttitle, [('movie', cntitle), ('multi', cntitle), ('movie', cuttitle), ('multi', cuttitle)])
             else:
                 searchList = [('multi', cntitle), ('multi', cuttitle)]
 
@@ -440,22 +456,39 @@ class TMDbNameParser():
         t = f.find_by_imdb_id(imdb_id=imdbid)
         if t:
             # print(t)
-            if t.movie_results:
-                self.tmdbcat = "movie"
-                r = t['movie_results'][0]
-                self.saveTmdbMovieResult(r)
-            elif t.tv_results:
-                self.tmdbcat = "tv"
-                r = t['tv_results'][0]
-                self.saveTmdbTVResultMatch(r)
-            else:
-                pass
+# (Pdb) p t.movie_results
+# [{'adult': False, 'backdrop_path': '/rcmjVmKBKONXk2LCe7GOAIHaIAO.jpg', 'id': 1068249, 'title': 'Reborn Rich', 'original_language': 'ko', 'original_title': '재벌집 막내아들', 'overview': '...', 'poster_path': '/xVtekQdaJ00cQqK2oyVJg5P7a6H.jpg', 'media_type': 'movie', 'genre_ids': [18, 14], 'popularity': 1.4, 'release_date': '2022-11-18', 'video': False, 'vote_average': 0.0, 'vote_count': 0}]
+# (Pdb) t.tv_results
+# [{'adult': False, 'backdrop_path': '/jG8mKDxe0LIDFBPB8uCeYGSBWCH.jpg', 'id': 153496, 'name': 'Reborn Rich', 'original_language': 'ko', 'original_name': '재벌집 막내아들', 'overview': '....', 'poster_path': '/ioywelRYOfNJ5w8aNQ5ttJo9dk1.jpg', 'media_type': 'tv', 'genre_ids': [18, 10765], 'popularity': 70.232, 'first_air_date': '2022-11-18', 'vote_average': 8.094, 'vote_count': 32, 'origin_country': ['KR']}]
+            if self.tmdbcat == "tv":
+                if t.tv_results:
+                    self.tmdbcat = "tv"
+                    r = t['tv_results'][0]
+                    self.saveTmdbTVResultMatch(r)
+                elif t.movie_results:
+                    self.tmdbcat = "movie"
+                    r = t['movie_results'][0]
+                    self.saveTmdbMovieResult(r)
+                else:
+                    pass
+            else: 
+                if t.movie_results:
+                    self.tmdbcat = "movie"
+                    r = t['movie_results'][0]
+                    self.saveTmdbMovieResult(r)
+                elif t.tv_results:
+                    self.tmdbcat = "tv"
+                    r = t['tv_results'][0]
+                    self.saveTmdbTVResultMatch(r)
+                else:
+                    pass
 
         return self.tmdbid, self.title, self.year
 
 
     def searchTMDbByTMDbIdTv(self, tmdbid):
         tv = TV(self.tmdb)
+        print("Search tmdbid in TV: " + tmdbid)
         try:
             t = tv.details(tmdbid)
             if t:
@@ -466,6 +499,7 @@ class TMDbNameParser():
 
     def searchTMDbByTMDbIdMovie(self, tmdbid):
         movie = Movie(self.tmdb)
+        print("Search tmdbid in Movie: " + tmdbid)
         try:
             m = movie.details(tmdbid)
             if m:
@@ -477,7 +511,7 @@ class TMDbNameParser():
     def searchTMDbByTMDbId(self, cat, tmdbid):
         if cat == 'tv':
             return self.searchTMDbByTMDbIdTv(tmdbid)
-        elif cat == 'move':
+        elif cat == 'movie':
             return self.searchTMDbByTMDbIdMovie(tmdbid)
         else:
             self.searchTMDbByTMDbIdTv(tmdbid)
